(function(root, factory) {
  if (typeof define === 'function' && define.amd) {
    // AMD. Register as an anonymous module.
    define(['ApiClient'], factory);
  } else if (typeof module === 'object' && module.exports) {
    // CommonJS-like environments that support module.exports, like Node.
    module.exports = factory(require('../ApiClient'));
  } else {
    // Browser globals (root is window)
    if (!root.OrbipayPaymentsapiClient) {
      root.OrbipayPaymentsapiClient = {};
    }
    root.OrbipayPaymentsapiClient.ErrorVo = factory(root.OrbipayPaymentsapiClient.ApiClient);
  }
}(this, function(ApiClient) {
  'use strict';




  /**
   * The ErrorVo model module.
   * @module models/ErrorVo
   */

  /**
   * <h3 style="color:red"> This class subject to change without prior notice, Please dont use this class directly. </h3>

   * Constructs a new <code>ErrorVo</code>.
   * @alias module:models/ErrorVo
   * @class
   * @param code {String} A string indicating error
   * @param message {String} A human-readable message providing more details about the error.
   */
  var exports = function(code, message) {
    var _this = this;

    _this['code'] = code;
    _this['message'] = message;

  };

  /**
   * Constructs a <code>ErrorVo</code> from a plain JavaScript object, optionally creating a new instance.
   * Copies all relevant properties from <code>data</code> to <code>obj</code> if supplied or a new instance if not.
   * @param {Object} data The plain JavaScript object bearing properties of interest.
   * @param {module:models/ErrorVo} obj Optional instance to populate.
   * @return {module:models/ErrorVo} The populated <code>ErrorVo</code> instance.
   */
  exports.constructFromObject = function(data, obj) {
    if (data) {
      obj = obj || new exports();

      if (data.hasOwnProperty('code')) {
        obj['code'] = ApiClient.convertToType(data['code'], 'String');
      }
      if (data.hasOwnProperty('message')) {
        obj['message'] = ApiClient.convertToType(data['message'], 'String');
      }
      if (data.hasOwnProperty('field')) {
        obj['field'] = ApiClient.convertToType(data['field'], 'String');
      }
    }
    return obj;
  };

  /**
   * A string indicating error
   * @member {String} code
   */
  exports.prototype['code'] = undefined;
  /**
   * A human-readable message providing more details about the error.
   * @member {String} message
   */
  exports.prototype['message'] = undefined;
  /**
   * Refers to the field in the request, if the error is specific to it.
   * @member {String} field
   */
  exports.prototype['field'] = undefined;



  return exports;
}));


