(function(root, factory) {
  if (typeof define === 'function' && define.amd) {
    // AMD. Register as an anonymous module.
    define(['ApiClient', 'models/AddressVo', 'models/UpdateCustomerAccountRequest'], factory);
  } else if (typeof module === 'object' && module.exports) {
    // CommonJS-like environments that support module.exports, like Node.
    module.exports = factory(require('../ApiClient'), require('./AddressVo'), require('./UpdateCustomerAccountRequest'));
  } else {
    // Browser globals (root is window)
    if (!root.OrbipayPaymentsapiClient) {
      root.OrbipayPaymentsapiClient = {};
    }
    root.OrbipayPaymentsapiClient.UpdateCustomerRequest = factory(root.OrbipayPaymentsapiClient.ApiClient, root.OrbipayPaymentsapiClient.AddressVo, root.OrbipayPaymentsapiClient.UpdateCustomerAccountRequest);
  }
}(this, function(ApiClient, AddressVo, UpdateCustomerAccountRequest) {
  'use strict';




  /**
   * The UpdateCustomerRequest model module.
   * @module models/UpdateCustomerRequest
   */

  /**
   * <h3 style="color:red"> This class subject to change without prior notice, Please dont use this class directly. </h3>

   * Constructs a new <code>UpdateCustomerRequest</code>.
   * @alias module:models/UpdateCustomerRequest
   * @class
   */
  var exports = function() {
    var _this = this;


















  };

  /**
   * Constructs a <code>UpdateCustomerRequest</code> from a plain JavaScript object, optionally creating a new instance.
   * Copies all relevant properties from <code>data</code> to <code>obj</code> if supplied or a new instance if not.
   * @param {Object} data The plain JavaScript object bearing properties of interest.
   * @param {module:models/UpdateCustomerRequest} obj Optional instance to populate.
   * @return {module:models/UpdateCustomerRequest} The populated <code>UpdateCustomerRequest</code> instance.
   */
  exports.constructFromObject = function(data, obj) {
    if (data) {
      obj = obj || new exports();

      if (data.hasOwnProperty('first_name')) {
        obj['first_name'] = ApiClient.convertToType(data['first_name'], 'String');
      }
      if (data.hasOwnProperty('last_name')) {
        obj['last_name'] = ApiClient.convertToType(data['last_name'], 'String');
      }
      if (data.hasOwnProperty('middle_name')) {
        obj['middle_name'] = ApiClient.convertToType(data['middle_name'], 'String');
      }
      if (data.hasOwnProperty('gender')) {
        obj['gender'] = ApiClient.convertToType(data['gender'], 'String');
      }
      if (data.hasOwnProperty('date_of_birth')) {
        obj['date_of_birth'] = ApiClient.convertToType(data['date_of_birth'], 'String');
      }
      if (data.hasOwnProperty('ssn')) {
        obj['ssn'] = ApiClient.convertToType(data['ssn'], 'String');
      }
      if (data.hasOwnProperty('locale')) {
        obj['locale'] = ApiClient.convertToType(data['locale'], 'String');
      }
      if (data.hasOwnProperty('email')) {
        obj['email'] = ApiClient.convertToType(data['email'], 'String');
      }
      if (data.hasOwnProperty('registered_email')) {
        obj['registered_email'] = ApiClient.convertToType(data['registered_email'], 'String');
      }
      if (data.hasOwnProperty('home_phone')) {
        obj['home_phone'] = ApiClient.convertToType(data['home_phone'], 'String');
      }
      if (data.hasOwnProperty('work_phone')) {
        obj['work_phone'] = ApiClient.convertToType(data['work_phone'], 'String');
      }
      if (data.hasOwnProperty('mobile_phone')) {
        obj['mobile_phone'] = ApiClient.convertToType(data['mobile_phone'], 'String');
      }
      if (data.hasOwnProperty('address')) {
        obj['address'] = AddressVo.constructFromObject(data['address']);
      }
      if (data.hasOwnProperty('custom_fields')) {
        obj['custom_fields'] = ApiClient.convertToType(data['custom_fields'], {'String': 'String'});
      }
      if (data.hasOwnProperty('status')) {
        obj['status'] = ApiClient.convertToType(data['status'], 'String');
      }
      if (data.hasOwnProperty('customer_accounts')) {
        obj['customer_accounts'] = ApiClient.convertToType(data['customer_accounts'], [UpdateCustomerAccountRequest]);
      }
      if (data.hasOwnProperty('comments')) {
        obj['comments'] = ApiClient.convertToType(data['comments'], 'String');
      }
    }
    return obj;
  };

  /**
   * The first name of the customer.
   * @member {String} first_name
   */
  exports.prototype['first_name'] = undefined;
  /**
   * The last name of the customer.
   * @member {String} last_name
   */
  exports.prototype['last_name'] = undefined;
  /**
   * The middle name of the customer.
   * @member {String} middle_name
   */
  exports.prototype['middle_name'] = undefined;
  /**
   * The gender of the customer.
   * @member {module:models/UpdateCustomerRequest.GenderEnum} gender
   */
  exports.prototype['gender'] = undefined;
  /**
   * The date of birth of the customer. It should be in the full-date format as per ISO8601, namely, YYYY-MM-DD.
   * @member {String} date_of_birth
   */
  exports.prototype['date_of_birth'] = undefined;
  /**
   * The SSN of the customer if the account holder is an individual or the tax ID, if the customer is a business.
   * @member {String} ssn
   */
  exports.prototype['ssn'] = undefined;
  /**
   * The language in which the customer wants the alerts and notifications from EBPP. This is to be specified in the format,<br><i>< <b>ISO-639-1 language code</b>  >_< <b>ISO ALPHA-2 Country Code</b> ></i>.<br> For e.g., <b>en_US</b> indicates the language preference as US English, which is also the default value.
   * @member {String} locale
   */
  exports.prototype['locale'] = undefined;
  /**
   * The email address of the customer to which notifications from EBPP will be sent.
   * @member {String} email
   */
  exports.prototype['email'] = undefined;
  /**
   * The email address of the customer registered with the client. This may be used to uniquely identify the customer if the client is set up accordingly in EBPP.
   * @member {String} registered_email
   */
  exports.prototype['registered_email'] = undefined;
  /**
   * The home phone number of the customer.
   * @member {String} home_phone
   */
  exports.prototype['home_phone'] = undefined;
  /**
   * The work phone number of the customer.
   * @member {String} work_phone
   */
  exports.prototype['work_phone'] = undefined;
  /**
   * The mobile phone number of the customer.
   * @member {String} mobile_phone
   */
  exports.prototype['mobile_phone'] = undefined;
  /**
   * @member {module:models/AddressVo} address
   */
  exports.prototype['address'] = undefined;
  /**
   * The additional information or meta-information that EBPP can accept, maintain and transmit back to the client. 
   * @member {Object.<String, String>} custom_fields
   */
  exports.prototype['custom_fields'] = undefined;
  /**
   * The status of the customer in EBPP.
   * @member {module:models/UpdateCustomerRequest.StatusEnum} status
   */
  exports.prototype['status'] = undefined;
  /**
   * @member {Array.<module:models/UpdateCustomerAccountRequest>} customer_accounts
   */
  exports.prototype['customer_accounts'] = undefined;
  /**
   * Comments that can be used to recollect the operation performed on the resource object.
   * @member {String} comments
   */
  exports.prototype['comments'] = undefined;


  /**
   * Allowed values for the <code>gender</code> property.
   * @enum {String}
   * @readonly
   */
  exports.GenderEnum = {
    /**
     * value: "male"
     * @const
     */
    "male": "male",
    /**
     * value: "female"
     * @const
     */
    "female": "female"  };

  /**
   * Allowed values for the <code>status</code> property.
   * @enum {String}
   * @readonly
   */
  exports.StatusEnum = {
    /**
     * value: "active"
     * @const
     */
    "active": "active",
    /**
     * value: "revoked"
     * @const
     */
    "revoked": "revoked",
    /**
     * value: "suspended"
     * @const
     */
    "suspended": "suspended"  };


  return exports;
}));


